# build_script.tcl: Tcl script for creating KRM3Z45 template Vivado Projects
#
#*****************************************************************************************

set module "KRM3Z45"
set part "xc7z045ffg676-1"

if {$argc == 1} {
	set proj_name [lindex $argv 0]
} else {
	set proj_name KRM3Z45_Template
}

# Set the reference directory to where the script is
set origin_dir [file dirname [info script]]

# Create project
create_project $proj_name $origin_dir/${proj_name}_Project

# Set the directory path for the new project
set proj_dir [get_property directory [current_project]]

# Set project properties
set obj [get_projects $proj_name]
set_property "default_lib" "xil_defaultlib" $obj
set_property "part" $part $obj
set_property "simulator_language" "Mixed" $obj
set_property "source_mgmt_mode" "DisplayOnly" $obj
set_property "target_language" "VHDL" $obj

# Create 'sources_1' fileset (if not found)
if {[string equal [get_filesets -quiet sources_1] ""]} {
  create_fileset -srcset sources_1
}

set obj [get_filesets sources_1]

# Add source hdl files
add_files -fileset sources_1 -norecurse -copy_to $proj_dir/${proj_name}.srcs/sources_1/new/ $origin_dir/src/hdl/top_level.vhd
add_files -fileset sources_1 -norecurse -copy_to $proj_dir/${proj_name}.srcs/sources_1/new/ $origin_dir/src/hdl/krc3701_usb_hub_reset.vhd

# Add package hdl files
add_files -fileset sources_1 -norecurse -copy_to $proj_dir/${proj_name}.srcs/sources_1/new/ $origin_dir/src/hdl/krc3701_pkg.vhd
set_property IS_GLOBAL_INCLUDE 1 [get_files $proj_dir/${proj_name}.srcs/sources_1/new/krc3701_pkg.vhd]

# Add IP blocks

# Create block design
 source $origin_dir/src/bd/block_design.tcl

# Generate the wrapper
 set design_name [get_bd_designs]
 make_wrapper -files [get_files $design_name.bd] -top -import

# Set 'sources_1' fileset properties
set obj [get_filesets sources_1]
set_property "top" "top_level" $obj

# Create 'constrs_1' fileset (if not found)
if {[string equal [get_filesets -quiet constrs_1] ""]} {
  create_fileset -constrset constrs_1
}

# Set 'constrs_1' fileset object
set obj [get_filesets constrs_1]

# Add/Import constrs file and set constrs file properties
add_files -fileset constrs_1 -norecurse -copy_to $proj_dir/${proj_name}.srcs/constr_1/new/ $origin_dir/src/constraints/${module}.xdc
add_files -fileset constrs_1 -norecurse -copy_to $proj_dir/${proj_name}.srcs/constr_1/new/ $origin_dir/src/constraints/user_constraints.xdc

# Set 'constrs_1' fileset properties
set obj [get_filesets constrs_1]
set_property "target_constrs_file" "${proj_dir}/${proj_name}.srcs/constr_1/new//user_constraints.xdc" $obj

puts "INFO: Project created:${proj_name}"
