-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- Copyright 2014, Knowledge Resources GmbH
-- http://www.knowres.ch
--
-- FILE:        krc3701_pkg.vhd
-- MODULE:      krc3701_pkg
-- TITLE:       KRC3701 Carrier Package
-------------------------------------------------------------------------------
-- DESCRIPTION: KRC3701 Carrier connector signal definitions.
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

package krc3701_pkg is

	-----------------------------------------------------------------------------
	-- NEW TYPES/CONSTANTS
	-----------------------------------------------------------------------------

	-----------------------------------------------------------------------------
	-- Auxiliary Constants
	--

	constant VEC32BITS_DW   : integer    := 32;
	constant VEC12BITS_DW   : integer    := 12;

	-----------------------------------------------------------------------------
	-- New Types
	--

	subtype vec12bits_t      is std_logic_vector(VEC12BITS_DW-1 downto 0);  
	subtype cnt32bits_t      is unsigned(VEC32BITS_DW-1 downto 0);  

	-----------------------------------------------------------------------------
	-- Group Definitions
	-----------------------------------------------------------------------------  

	type iogroup_t is record
	t0		: vec12bits_t;                     -- T0
	t1		: vec12bits_t;                     -- T1
	t2		: vec12bits_t;                     -- T2
	t3		: vec12bits_t;                     -- T3
	end record;

	type mgtgroup0_t is record
	TX_00_P : std_logic;
	TX_00_N : std_logic;
	RX_00_P : std_logic;
	RX_00_N : std_logic;
	TX_01_P : std_logic;
	TX_01_N : std_logic;
	RX_01_P : std_logic;
	RX_01_N : std_logic;
	TX_02_P : std_logic;
	TX_02_N : std_logic;
	RX_02_P : std_logic;
	RX_02_N : std_logic;
	TX_03_P : std_logic;
	TX_03_N : std_logic;
	RX_03_P : std_logic;
	RX_03_N : std_logic;
	
	CLK_0_P : std_logic;
	CLK_0_N : std_logic;

	end record;
	
	type mgtgroup1_t is record
	TX_04_P : std_logic;
	TX_04_N : std_logic;
	RX_04_P : std_logic;
	RX_04_N : std_logic;
	TX_05_P : std_logic;
	TX_05_N : std_logic;
	RX_05_P : std_logic;
	RX_05_N : std_logic;
	TX_06_P : std_logic;
	TX_06_N : std_logic;
	RX_06_P : std_logic;
	RX_06_N : std_logic;
	TX_07_P : std_logic;
	TX_07_N : std_logic;
	RX_07_P : std_logic;
	RX_07_N : std_logic;
	
	CLK_1_P : std_logic;
	CLK_1_N : std_logic;
	end record;
	
	
	-----------------------------------------------------------------------------
	-- USB Hub Reset Module
	-----------------------------------------------------------------------------  
	
	component krc3701_usb_hub_reset is
	Generic (
	NBITS : integer := 8;
	CNT_MAX : integer := 255
	);
	Port ( 
	clk : in STD_LOGIC;
	USB_HUB_RESET : out STD_LOGIC
	);
	end component;
	
	end krc3701_pkg;